@@ -1,11 +1,12 @@
 from django.contrib import admin
+from edc_model_admin.mixins import TemplatesModelAdminMixin
 
 from .admin_site import edc_reference_admin
 from .models import Reference
 
 
 @admin.register(Reference, site=edc_reference_admin)
-class ReferenceAdmin(admin.ModelAdmin):
+class ReferenceAdmin(TemplatesModelAdminMixin, admin.ModelAdmin):
 
     date_hierarchy = "report_datetime"
 
