@@ -25,8 +25,8 @@ class ReferenceDeleter:
     @property
     def options(self):
         return dict(
-            identifier=self.model_obj.visit.subject_identifier,
-            report_datetime=self.model_obj.visit.report_datetime,
-            timepoint=self.model_obj.visit.timepoint,
+            identifier=self.model_obj.related_visit.subject_identifier,
+            report_datetime=self.model_obj.related_visit.report_datetime,
+            timepoint=self.model_obj.related_visit.timepoint,
             model=self.model_obj.reference_name,
         )
