@@ -420,7 +420,9 @@ class TestReferenceModel(TestCase):
         integer = 100
         crf_one = CrfOne.objects.create(subject_visit=self.subject_visit, field_int=integer)
         reference = ReferenceGetter(
-            name="reference_app.crfone", field_name="field_int", visit_obj=crf_one.visit
+            name="reference_app.crfone",
+            field_name="field_int",
+            visit_obj=crf_one.related_visit,
         )
         self.assertEqual(reference.field_int, integer)
 
@@ -435,12 +437,12 @@ class TestReferenceModel(TestCase):
             name="reference_app.crfone",
             field_name="field_int",
             subject_identifier=self.subject_identifier,
-            report_datetime=crf_one.visit.report_datetime,
-            visit_schedule_name=crf_one.visit.visit_schedule_name,
-            schedule_name=crf_one.visit.schedule_name,
-            visit_code=crf_one.visit.visit_code,
-            visit_code_sequence=crf_one.visit.visit_code_sequence,
-            timepoint=crf_one.visit.timepoint,
+            report_datetime=crf_one.related_visit.report_datetime,
+            visit_schedule_name=crf_one.related_visit.visit_schedule_name,
+            schedule_name=crf_one.related_visit.schedule_name,
+            visit_code=crf_one.related_visit.visit_code,
+            visit_code_sequence=crf_one.related_visit.visit_code_sequence,
+            timepoint=crf_one.related_visit.timepoint,
         )
         reference = ReferenceGetter(**opts)
         self.assertEqual(reference.field_int, integer)
@@ -456,11 +458,11 @@ class TestReferenceModel(TestCase):
             name="reference_app.crfone",
             field_name="field_int",
             subject_identifier=self.subject_identifier,
-            report_datetime=crf_one.visit.report_datetime,
-            visit_schedule_name=crf_one.visit.visit_schedule_name,
-            schedule_name=crf_one.visit.schedule_name,
-            visit_code=crf_one.visit.visit_code,
-            timepoint=crf_one.visit.timepoint,
+            report_datetime=crf_one.related_visit.report_datetime,
+            visit_schedule_name=crf_one.related_visit.visit_schedule_name,
+            schedule_name=crf_one.related_visit.schedule_name,
+            visit_code=crf_one.related_visit.visit_code,
+            timepoint=crf_one.related_visit.timepoint,
         )
         reference = ReferenceGetter(**opts)
         self.assertEqual(reference.field_int, integer)
