@@ -1,14 +1,14 @@
-from django.conf import settings
 from django.contrib.auth.decorators import login_required
 from django.utils.decorators import method_decorator
 from django.views.generic.base import TemplateView
+from edc_dashboard.utils import get_bootstrap_version
 from edc_dashboard.view_mixins import EdcViewMixin
 from edc_navbar import NavbarViewMixin
 
 
 class HomeView(EdcViewMixin, NavbarViewMixin, TemplateView):
 
-    template_name = f"edc_reference/bootstrap{settings.EDC_BOOTSTRAP}/home.html"
+    template_name = f"edc_reference/bootstrap{get_bootstrap_version()}/home.html"
     navbar_name = "edc_reference"
     navbar_selected_item = "reference"
 
